@@ -126,7 +126,7 @@ sub remove { shift->replace('') }
 sub replace {
   my ($self, $new) = @_;
   return $self->parse($new) if (my $tree = $self->tree)->[0] eq 'root';
-  return $self->_replace($self->_parent, $tree, $self->_parse($new));
+  return $self->_replace($self->_parent, $tree, _nodes($self->_parse($new)));
 }
 
 sub root {
@@ -138,7 +138,7 @@ sub root {
 sub strip {
   my $self = shift;
   return $self if (my $tree = $self->tree)->[0] ne 'tag';
-  return $self->_replace($tree->[3], $tree, ['root', _nodes($tree)]);
+  return $self->_replace($tree->[3], $tree, _nodes($tree));
 }
 
 sub tag {
@@ -159,6 +159,20 @@ sub tree { shift->_delegate(tree => @_) }
 
 sub type { shift->tree->[0] }
 
+sub val {
+  my $self = shift;
+
+  # "option"
+  return $self->{value} // $self->text if (my $tag = $self->tag) eq 'option';
+
+  # "textarea", "input" or "button"
+  return $tag eq 'textarea' ? $self->text : $self->{value} if $tag ne 'select';
+
+  # "select"
+  my $v = $self->find('option:checked')->map('val');
+  return exists $self->{multiple} ? $v->size ? $v->to_array : undef : $v->last;
+}
+
 sub wrap         { shift->_wrap(0, @_) }
 sub wrap_content { shift->_wrap(1, @_) }
 
@@ -171,7 +185,7 @@ sub _add {
 
   my $parent = $self->_parent;
   splice @$parent, _offset($parent, $tree) + $offset, 0,
-    _link($self->_parse($new), $parent);
+    _link($parent, _nodes($self->_parse($new)));
 
   return $self;
 }
@@ -185,10 +199,9 @@ sub _all_text {
 
   # Detect "pre" tag
   my $tree = $self->tree;
-  if (!defined $trim || $trim) {
-    $trim = 1;
-    $_->[1] eq 'pre' and $trim = 0 for $self->_ancestors, $tree;
-  }
+  $trim = 1 unless defined $trim;
+  map { $_->[1] eq 'pre' and $trim = 0 } $self->_ancestors, $tree
+    if $trim && $tree->[0] ne 'root';
 
   return _text([_nodes($tree)], $recurse, $trim);
 }
@@ -222,7 +235,7 @@ sub _content {
 
   $start  = $start  ? ($#$tree + 1) : _start($tree);
   $offset = $offset ? $#$tree       : 0;
-  splice @$tree, $start, $offset, _link($self->_parse($new), $tree);
+  splice @$tree, $start, $offset, _link($tree, _nodes($self->_parse($new)));
 
   return $self;
 }
@@ -237,17 +250,16 @@ sub _delegate {
 }
 
 sub _link {
-  my ($children, $parent) = @_;
+  my ($parent, @children) = @_;
 
   # Link parent to children
-  my @new = @$children[1 .. $#$children];
-  for my $node (@new) {
+  for my $node (@children) {
     my $offset = $node->[0] eq 'tag' ? 3 : 2;
     $node->[$offset] = $parent;
     weaken $node->[$offset];
   }
 
-  return @new;
+  return @children;
 }
 
 sub _maybe { $_[1] ? $_[0]->_build($_[1], $_[0]->xml) : undef }
@@ -270,8 +282,8 @@ sub _parent { $_[0]->tree->[$_[0]->type eq 'tag' ? 3 : 2] }
 sub _parse { Mojo::DOM::HTML->new(xml => shift->xml)->parse(shift)->tree }
 
 sub _replace {
-  my ($self, $parent, $tree, $new) = @_;
-  splice @$parent, _offset($parent, $tree), 1, _link($new, $parent);
+  my ($self, $parent, $tree, @nodes) = @_;
+  splice @$parent, _offset($parent, $tree), 1, _link($parent, @nodes);
   return $self->parent;
 }
 
@@ -350,14 +362,14 @@ sub _wrap {
 
   # Wrap content
   if ($content) {
-    push @$current, _link(['root', _nodes($tree)], $current);
-    splice @$tree, _start($tree), $#$tree, _link($new, $tree);
+    push @$current, _link($current, _nodes($tree));
+    splice @$tree, _start($tree), $#$tree, _link($tree, _nodes($new));
     return $self;
   }
 
   # Wrap element
-  $self->_replace($self->_parent, $tree, $new);
-  push @$current, _link(['root', $tree], $current);
+  $self->_replace($self->_parent, $tree, _nodes($new));
+  push @$current, _link($current, $tree);
   return $self;
 }
 
@@ -402,27 +414,57 @@ L<Mojo::DOM> is a minimalistic and relaxed HTML/XML DOM parser with CSS
 selector support. It will even try to interpret broken HTML and XML, so you
 should not use it for validation.
 
+=head1 NODES AND ELEMENTS
+
+When we parse an HTML/XML fragment, it gets turned into a tree of nodes.
+
+  <!DOCTYPE html>
+  <html>
+    <head><title>Hello</title></head>
+    <body>World!</body>
+  </html>
+
+There are currently eight different kinds of nodes, C<cdata>, C<comment>,
+C<doctype>, C<pi>, C<raw>, C<root>, C<tag> and C<text>. Elements are nodes of
+the type C<tag>.
+
+  root
+  |- doctype (html)
+  +- tag (html)
+     |- tag (head)
+     |  +- tag (title)
+     |     +- raw (Hello)
+     +- tag (body)
+        +- text (World!)
+
+While all node types are represented as L<Mojo::DOM> objects, some methods like
+L</"attr"> and L</"namespace"> only apply to elements.
+
 =head1 CASE-SENSITIVITY
 
 L<Mojo::DOM> defaults to HTML semantics, that means all tags and attribute
 names are lowercased and selectors need to be lowercase as well.
 
+  # HTML semantics
   my $dom = Mojo::DOM->new('<P ID="greeting">Hi!</P>');
   say $dom->at('p[id]')->text;
 
 If XML processing instructions are found, the parser will automatically switch
 into XML mode and everything becomes case-sensitive.
 
+  # XML semantics
   my $dom = Mojo::DOM->new('<?xml version="1.0"?><P ID="greeting">Hi!</P>');
   say $dom->at('P[ID]')->text;
 
 XML detection can also be disabled with the L</"xml"> method.
 
   # Force XML semantics
-  $dom->xml(1);
+  my $dom = Mojo::DOM->new->xml(1)->parse('<P ID="greeting">Hi!</P>');
+  say $dom->at('P[ID]')->text;
 
   # Force HTML semantics
-  $dom->xml(0);
+  my $dom = Mojo::DOM->new->xml(0)->parse('<P ID="greeting">Hi!</P>');
+  say $dom->at('p[id]')->text;
 
 =head1 METHODS
 
@@ -506,6 +548,12 @@ All selectors from L<Mojo::DOM::CSS/"SELECTORS"> are supported.
 
 This element's attributes.
 
+  # Remove an attribute
+  delete $dom->attr->{id};
+
+  # Attribute without value
+  $dom->attr(selected => undef);
+
   # List id attributes
   say $dom->find('*')->map(attr => 'id')->compact->join("\n");
 
@@ -519,8 +567,11 @@ as L<Mojo::DOM> objects.
   # "<p><b>123</b></p>"
   $dom->parse('<p>Test<b>123</b></p>')->at('p')->child_nodes->first->remove;
 
-  # "<!-- Test -->"
-  $dom->parse('<!-- Test --><b>123</b>')->child_nodes->first;
+  # "<!DOCTYPE html>"
+  $dom->parse('<!DOCTYPE html><b>123</b>')->child_nodes->first;
+
+  # " Test "
+  $dom->parse('<b>123</b><!-- Test -->')->child_nodes->last->content;
 
 =head2 children
 
@@ -779,7 +830,7 @@ no more siblings.
 
   my $parent = $dom->remove;
 
-Remove this node and return L</"parent">.
+Remove this node and return L</"root"> (for C<root> nodes) or L</"parent">.
 
   # "<div></div>"
   $dom->parse('<div><h1>Test</h1></div>')->at('h1')->remove;
@@ -792,7 +843,8 @@ Remove this node and return L</"parent">.
 
   my $parent = $dom->replace('<div>I ♥ Mojolicious!</div>');
 
-Replace this node with HTML/XML fragment and return L</"parent">.
+Replace this node with HTML/XML fragment and return L</"root"> (for C<root>
+nodes) or L</"parent">.
 
   # "<div><h2>123</h2></div>"
   $dom->parse('<div><h1>Test</h1></div>')->at('h1')->replace('<h2>123</h2>');
@@ -805,7 +857,7 @@ Replace this node with HTML/XML fragment and return L</"parent">.
 
   my $root = $dom->root;
 
-Return L<Mojo::DOM> object for root node.
+Return L<Mojo::DOM> object for C<root> node.
 
 =head2 strip
 
@@ -870,6 +922,57 @@ carefully since it is very dynamic.
 This node's type, usually C<cdata>, C<comment>, C<doctype>, C<pi>, C<raw>,
 C<root>, C<tag> or C<text>.
 
+  # "cdata"
+  $dom->parse('<![CDATA[Test]]>')->child_nodes->first->type;
+
+  # "comment"
+  $dom->parse('<!-- Test -->')->child_nodes->first->type;
+
+  # "doctype"
+  $dom->parse('<!DOCTYPE html>')->child_nodes->first->type;
+
+  # "pi"
+  $dom->parse('<?xml version="1.0"?>')->child_nodes->first->type;
+
+  # "raw"
+  $dom->parse('<title>Test</title>')->at('title')->child_nodes->first->type;
+
+  # "root"
+  $dom->parse('<p>Test</p>')->type;
+
+  # "tag"
+  $dom->parse('<p>Test</p>')->at('p')->type;
+
+  # "text"
+  $dom->parse('<p>Test</p>')->at('p')->child_nodes->first->type;
+
+=head2 val
+
+  my $value = $dom->val;
+
+Extract value from form element (such as C<button>, C<input>, C<option>,
+C<select> and C<textarea>) or return C<undef> if this element has no value. In
+the case of C<select> with C<multiple> attribute, find C<option> elements with
+C<selected> attribute and return an array reference with all values or C<undef>
+if none could be found.
+
+  # "a"
+  $dom->parse('<input name="test" value="a">')->at('input')->val;
+
+  # "b"
+  $dom->parse('<textarea>b</textarea>')->at('textarea')->val;
+
+  # "c"
+  $dom->parse('<option value="c">Test</option>')->at('option')->val;
+
+  # "d"
+  $dom->parse('<select><option selected>d</option></select>')
+    ->at('select')->val;
+
+  # "e"
+  $dom->parse('<select multiple><option selected>e</option></select>')
+    ->at('select')->val->[0];
+
 =head2 wrap
 
   $dom = $dom->wrap('<div></div>');
