@@ -8,16 +8,10 @@ has tree => sub { ['root'] };
 has 'xml';
 
 my $ATTR_RE = qr/
-  ([^<>=\s\/]+|\/)   # Key
+  ([^<>=\s\/]+|\/)                    # Key
   (?:
     \s*=\s*
-    (?:
-      "([^"]*?)"     # Quotation marks
-    |
-      '([^']*?)'     # Apostrophes
-    |
-      ([^>\s]*)      # Unquoted
-    )
+    (?:(["'])(.*?)\g{-2}|([^>\s]*))   # Value
   )?
   \s*
 /x;
@@ -126,7 +120,7 @@ sub parse {
         # Attributes
         my (%attrs, $closing);
         while ($attr =~ /$ATTR_RE/go) {
-          my ($key, $value) = ($xml ? $1 : lc $1, $2 // $3 // $4);
+          my ($key, $value) = ($xml ? $1 : lc $1, $3 // $4);
 
           # Empty tag
           ++$closing and next if $key eq '/';
