@@ -2,13 +2,14 @@ package Mojo::Message::Request;
 use Mojo::Base 'Mojo::Message';
 
 use Mojo::Cookie::Request;
-use Mojo::Util qw(b64_encode b64_decode);
+use Mojo::Util qw(b64_encode b64_decode deprecated);
 use Mojo::URL;
 
 has env => sub { {} };
 has method => 'GET';
-has url => sub { Mojo::URL->new };
 has 'reverse_proxy';
+has url => sub { Mojo::URL->new };
+has via_proxy => 1;
 
 sub clone {
   my $self = shift;
@@ -35,12 +36,9 @@ sub cookies {
     unless @_;
 
   # Add cookies
-  my @cookies = $headers->cookie || ();
-  for my $cookie (@_) {
-    $cookie = Mojo::Cookie::Request->new($cookie) if ref $cookie eq 'HASH';
-    push @cookies, $cookie;
-  }
-  $headers->cookie(join('; ', @cookies));
+  my @cookies = map { ref $_ eq 'HASH' ? Mojo::Cookie::Request->new($_) : $_ }
+    $headers->cookie || (), @_;
+  $headers->cookie(join '; ', @cookies);
 
   return $self;
 }
@@ -75,8 +73,8 @@ sub fix_headers {
   }
 
   # Basic proxy authentication
-  return $self unless my $proxy = $self->proxy;
-  return $self unless my $info  = $proxy->userinfo;
+  return $self unless (my $proxy = $self->proxy) && $self->via_proxy;
+  return $self unless my $info = $proxy->userinfo;
   $headers->proxy_authorization('Basic ' . b64_encode($info, ''))
     unless $headers->proxy_authorization;
   return $self;
@@ -84,30 +82,7 @@ sub fix_headers {
 
 sub get_start_line_chunk {
   my ($self, $offset) = @_;
-
-  unless (defined $self->{start_buffer}) {
-
-    # Path
-    my $url  = $self->url;
-    my $path = $url->path_query;
-    $path = "/$path" unless $path =~ m!^/!;
-
-    # CONNECT
-    my $method = uc $self->method;
-    if ($method eq 'CONNECT') {
-      my $port = $url->port || ($url->protocol eq 'https' ? '443' : '80');
-      $path = $url->ihost . ":$port";
-    }
-
-    # Proxy
-    elsif ($self->proxy && $url->protocol ne 'https') {
-      $path = $url->clone->userinfo(undef) unless $self->is_handshake;
-    }
-
-    $self->{start_buffer} = "$method $path HTTP/@{[$self->version]}\x0d\x0a";
-  }
-
-  $self->emit(progress => 'start_line', $offset);
+  $self->_start_line->emit(progress => 'start_line', $offset);
   return substr $self->{start_buffer}, $offset, 131072;
 }
 
@@ -169,15 +144,28 @@ sub parse {
   return $self;
 }
 
+# DEPRECATED in Clinking Beer Mugs!
 sub proxy {
   my $self = shift;
+
   return $self->{proxy} unless @_;
-  $self->{proxy} = !$_[0] || ref $_[0] ? shift : Mojo::URL->new(shift);
+
+  deprecated 'Calling Mojo::Message::Request::proxy with a boolean argument is'
+    . ' DEPRECATED in favor of Mojo::Message::Request::via_proxy'
+    and return $self->via_proxy(0)
+    unless $_[0];
+  deprecated
+    'Calling Mojo::Message::Request::proxy with a string argument is DEPRECATED'
+    unless ref $_[0];
+
+  $self->{proxy} = ref $_[0] ? shift : Mojo::URL->new(shift);
   return $self;
 }
 
 sub query_params { shift->url->query }
 
+sub start_line_size { length shift->_start_line->{start_buffer} }
+
 sub _parse_basic_auth {
   return undef unless my $header = shift;
   return $header =~ /Basic (.+)$/ ? b64_decode $1 : undef;
@@ -244,6 +232,33 @@ sub _parse_env {
   $self->{state} = 'cgi';
 }
 
+sub _start_line {
+  my $self = shift;
+
+  return $self if defined $self->{start_buffer};
+
+  # Path
+  my $url  = $self->url;
+  my $path = $url->path_query;
+  $path = "/$path" unless $path =~ m!^/!;
+
+  # CONNECT
+  my $method = uc $self->method;
+  if ($method eq 'CONNECT') {
+    my $port = $url->port || ($url->protocol eq 'https' ? '443' : '80');
+    $path = $url->ihost . ":$port";
+  }
+
+  # Proxy
+  elsif ($self->proxy && $self->via_proxy && $url->protocol ne 'https') {
+    $path = $url->clone->userinfo(undef) unless $self->is_handshake;
+  }
+
+  $self->{start_buffer} = "$method $path HTTP/@{[$self->version]}\x0d\x0a";
+
+  return $self;
+}
+
 1;
 
 =encoding utf8
@@ -309,6 +324,20 @@ Direct access to the C<CGI> or C<PSGI> environment hash if available.
 
 HTTP request method, defaults to C<GET>.
 
+=head2 proxy
+
+  my $url = $req->proxy;
+  $req    = $req->proxy(Mojo::URL->new('http://127.0.0.1:3000'));
+
+Proxy URL for request.
+
+=head2 reverse_proxy
+
+  my $bool = $req->reverse_proxy;
+  $req     = $req->reverse_proxy($bool);
+
+Request has been performed through a reverse proxy.
+
 =head2 url
 
   my $url = $req->url;
@@ -321,12 +350,12 @@ HTTP request URL, defaults to a L<Mojo::URL> object.
   my $host = $req->url->to_abs->host;
   my $path = $req->url->to_abs->path;
 
-=head2 reverse_proxy
+=head2 via_proxy
 
-  my $bool = $req->reverse_proxy;
-  $req     = $req->reverse_proxy($bool);
+  my $bool = $req->via_proxy;
+  $req     = $req->via_proxy($bool);
 
-Request has been performed through a reverse proxy.
+Request can be performed through a proxy server.
 
 =head1 METHODS
 
@@ -376,7 +405,8 @@ Make sure request has all required headers.
 
   my $bytes = $req->get_start_line_chunk($offset);
 
-Get a chunk of request-line data starting from a specific position.
+Get a chunk of request-line data starting from a specific position. Note that
+this method finalizes the request.
 
 =head2 is_handshake
 
@@ -432,17 +462,6 @@ default.
 
 Parse HTTP request chunks or environment hash.
 
-=head2 proxy
-
-  my $proxy = $req->proxy;
-  $req      = $req->proxy('http://foo:bar@127.0.0.1:3000');
-  $req      = $req->proxy(Mojo::URL->new('http://127.0.0.1:3000'));
-
-Proxy URL for request.
-
-  # Disable proxy
-  $req->proxy(0);
-
 =head2 query_params
 
   my $params = $req->query_params;
@@ -452,6 +471,12 @@ All C<GET> parameters, usually a L<Mojo::Parameters> object.
   # Turn GET parameters to hash and extract value
   say $req->query_params->to_hash->{foo};
 
+=head2 start_line_size
+
+  my $size = $req->start_line_size;
+
+Size of the request-line in bytes. Note that this method finalizes the request.
+
 =head1 SEE ALSO
 
 L<Mojolicious>, L<Mojolicious::Guides>, L<http://mojolicio.us>.
