@@ -158,7 +158,7 @@ sub _listen {
     reuse   => $query->param('reuse')
   };
   if (my $port = $url->port) { $options->{port} = $port }
-  $options->{"tls_$_"} = $query->param($_) for qw(ca cert ciphers key);
+  $options->{"tls_$_"} = $query->param($_) for qw(ca cert ciphers key version);
   my $verify = $query->param('verify');
   $options->{tls_verify} = hex $verify if defined $verify;
   delete $options->{address} if $options->{address} eq '*';
@@ -380,7 +380,7 @@ These parameters are currently available:
 
   ca=/etc/tls/ca.crt
 
-Path to TLS certificate authority file.
+Path to TLS certificate authority file used to verify the peer certificate.
 
 =item cert
 
@@ -392,7 +392,8 @@ Path to the TLS cert file, defaults to a built-in test certificate.
 
   ciphers=AES128-GCM-SHA256:RC4:HIGH:!MD5:!aNULL:!EDH
 
-Cipher specification string.
+TLS cipher specification string. For more information about the format see
+L<https://www.openssl.org/docs/manmaster/apps/ciphers.html#CIPHER-STRINGS>.
 
 =item key
 
@@ -413,6 +414,12 @@ option.
 
 TLS verification mode, defaults to C<0x03>.
 
+=item version
+
+  version=TLSv1_2
+
+TLS protocol version.
+
 =back
 
 =head2 max_clients
@@ -447,13 +454,13 @@ implements the following new ones.
 
   $daemon->run;
 
-Run server.
+Run server and wait for L</"SIGNALS">.
 
 =head2 start
 
   $daemon = $daemon->start;
 
-Start accepting connections.
+Start accepting connections through L</"ioloop">.
 
   # Listen on random port
   my $id   = $daemon->listen(['http://127.0.0.1'])->start->acceptors->[0];
@@ -463,7 +470,7 @@ Start accepting connections.
 
   $daemon = $daemon->stop;
 
-Stop accepting connections.
+Stop accepting connections through L</"ioloop">.
 
 =head1 DEBUGGING
 
