@@ -77,8 +77,7 @@ sub _html {
 
   # Combine everything to a proper response
   $c->content_for(perldoc => "$dom");
-  my $template = $c->app->renderer->_bundled('perldoc');
-  $c->render(inline => $template, title => $title, parts => \@parts);
+  $c->render('mojo/perldoc', title => $title, parts => \@parts);
 }
 
 sub _perldoc {
@@ -119,9 +118,9 @@ Mojolicious::Plugin::PODRenderer - POD renderer plugin
 =head1 SYNOPSIS
 
   # Mojolicious (with documentation browser under "/perldoc")
-  my $route = $self->plugin('PODRenderer');
-  my $route = $self->plugin(PODRenderer => {name => 'foo'});
-  my $route = $self->plugin(PODRenderer => {preprocess => 'epl'});
+  my $route = $app->plugin('PODRenderer');
+  my $route = $app->plugin(PODRenderer => {name => 'foo'});
+  my $route = $app->plugin(PODRenderer => {preprocess => 'epl'});
 
   # Mojolicious::Lite (with documentation browser under "/perldoc")
   my $route = plugin 'PODRenderer';
